
"""
常用装饰器
"""
import allure
from tools import log_tool
from tools import string_tool



# 日志装饰器
def logs(func):
    def _func(*args, **kwargs):
        r= func(*args, **kwargs)
        request = "---------------请求-----------------" \
                  "\n{0}\n{1}\n{2}".format(r.url,string_tool.dic_to_str(r.request.headers),r.request.body)
        log_tool.info(request)
        response = "---------------响应----------------" \
                   "\n{0}\n{1}\n{2}".format(r.status_code,string_tool.dic_to_str(r.headers),r.text)
        log_tool.info(response)
        allure.attach(request,'请求',allure.attachment_type.TEXT)
        allure.attach(response, '响应', allure.attachment_type.TEXT)
        return r

    return _func


# -*- coding:utf-8 -*-
# Author : 小吴老师
# Data ：2019/7/21 14:53
import hashlib

def md5_passwd(str,key='123456'):
    #satl是盐值，默认是123456
    str=str+key
    md = hashlib.md5()  # 构造一个md5对象
    md.update(str.encode())
    res = md.hexdigest()
    return res



"""
封装执行shell语句方法
"""

import subprocess
from tools import log_tool


def invoke(cmd):
    try:
        output, errors = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
        o = output.decode("utf-8")
        print(o)
        return o
    except Exception as e:
        log_tool.error('执行命令失败，请检查环境配置')
        log_tool.error(e)
        raise




"""
封装request
"""

import requests
from tools import log_tool
from tools.decorators_tool import logs
import time

@logs
def get_request(url, params=None, headers=None, cookies=None):
    """
    Get请求
    :param url:
    :param data:
    :param header:
    :return:
    """

    if not (url.startswith('http://') or url.startswith('https://')):
        url = '%s%s' % ('http://', url)
        print(url)
    try:

        response = requests.get(url=url, params=params, headers=headers, cookies=cookies)

    except requests.RequestException as e:
        log_tool.error('%s%s' % ('Exception url: ', url))
        log_tool.error(e)
        return ()

    except Exception as e:
        log_tool.error('%s%s' % ('Exception url: ', url))
        return ()

    time_consuming = response.elapsed.microseconds / 1000
    log_tool.info('----请求用时: %s 秒数' % time_consuming)

    return response


@logs
def post_request(url, data=None,files=None, params=None, headers=None, json=None, cookies=None):
    """
    Post请求
    :param url:
    :param data:
    :param header:
    :return:
    """
    if not (url.startswith('http://') or url.startswith('https://')):
        url = '%s%s' % ('http://', url)
        print(url)
    try:
        response = requests.post(url, data=data,files=files, params=params, headers=headers, json=json, cookies=cookies)

    except requests.RequestException as e:
        log_tool.error('%s%s' % ('RequestException url: ', url))
        log_tool.error(e)
        return ()

    except Exception as e:
        log_tool.error('%s%s' % ('Exception url: ', url))
        log_tool.error(e)
        return ()

    # time_consuming为响应时间，单位为毫秒
    time_consuming = response.elapsed.microseconds / 1000
    log_tool.info('----请求用时: %s 秒数' % time_consuming)

    return response


@logs
def post_request_multipart(url, files=None, headers=None, cookies=None):
    """
    提交Multipart/form-data 格式的Post请求
    :param url:
    :param data:
    :param header:
    :param file_parm:
    :param file:
    :param type:
    :return:
    """
    if not (url.startswith('http://') or url.startswith('https://')):
        url = '%s%s' % ('http://', url)
        print(url)
    response = requests.post(url=url, files=files, headers=headers, cookies=cookies)
    # time_consuming为响应时间，单位为毫秒
    time_consuming = response.elapsed.microseconds / 1000
    log_tool.info('----请求用时: %s 秒数' % time_consuming)

    return response


@logs
def put_request(url, data, header=None, cookies=None):
    """
    Put请求
    :param url:
    :param data:
    :param header:
    :return:
    """
    if not (url.startswith('http://') or url.startswith('https://')):
        url = '%s%s' % ('http://', url)
        log_tool.debug(url)

    try:
        if data is None:
            response = requests.put(url=url, headers=header, cookies=cookies)
        else:
            response = requests.put(url=url, params=data, headers=header, cookies=cookies)

    except requests.RequestException as e:
        log_tool.error('%s%s' % ('RequestException url: ', url))
        log_tool.error(e)
        return ()

    except Exception as e:
        print('%s%s' % ('Exception url: ', url))
        print(e)
        return ()

    time_consuming = response.elapsed.microseconds / 1000
    log_tool.info('----请求用时: %s 秒数' % time_consuming)

    return response

def down_big_file(srcUrl, localFile):
    print('%s\n --->>>\n  %s' % (srcUrl, localFile))
    startTime = time.time()
    with requests.get(srcUrl, stream=True) as r:
        contentLength = int(r.headers['content-length'])
        line = 'content-length: %dB/ %.2fKB/ %.2fMB'
        line = line % (contentLength, contentLength / 1024, contentLength / 1024 / 1024)
        print(line)
        print('正在下载中..............')
        downSize = 0
        with open(localFile, 'wb') as f:
            for chunk in r.iter_content(8192):
                if chunk:
                    f.write(chunk)
                downSize += len(chunk)
                line = '%d KB/s - %.2f MB， 共 %.2f MB'
                line = line % (
                downSize / 1024 / (time.time() - startTime), downSize / 1024 / 1024, contentLength / 1024 / 1024)
                print(line, end='\r')
                if downSize >= contentLength:
                    break
        timeCost = time.time() - startTime
        line = '共耗时: %.2f s, 平均速度: %.2f KB/s'
        line = line % (timeCost, downSize / 1024 / timeCost)
        print(line)

def copy_github_file(url,save_name):
    resp = get_request(url)
    body = resp.text
    with open(save_name, 'w', encoding='utf-8') as file:
        file.write(body)


# -*- coding:utf-8 -*-
# Author : 小吴老师
# Data ：2019/7/31 22:47
import yaml

def get_yaml(yaml_path):
    with open(yaml_path,'r',encoding='utf-8') as f:
        content =yaml.load(f.read(),Loader=yaml.FullLoader)
    return content


"""
封装Assert方法

"""
from tools import log_tool
import json


def assert_in(body, expected_msg):
    """
    验证response body中是否包含预期字符串
    :param body:
    :param expected_msg:
    :return:
    """
    try:
        text = json.dumps(body, ensure_ascii=False)
        # print(text)
        assert expected_msg in text
        return True

    except:
        log_tool.error("不包含期望值, 期望值 是  %s" % expected_msg)
        raise


def assert_equal(body, expected_msg):
    """
    验证response body中是否等于预期字符串
    :param body:
    :param expected_msg:
    :return:
    """
    try:
        assert body == expected_msg
        return True
    except:
        log_tool.error("Response body != expected_msg, expected_msg is %s, body is %s" % (expected_msg, body))
        raise


def assert_time(time, expected_time):
    """
    验证response body响应时间小于预期最大响应时间,单位：毫秒
    :param body:
    :param expected_time:
    :return:
    """
    try:
        assert time < expected_time
        return True

    except:
        log_tool.error("Response time > expected_time, expected_time is %s, time is %s" % (expected_time, time))
        raise


def assert_not_null(actual):
    """
            验证实际结果不为null
            :param actual:
            :return:
            """
    try:
        assert actual != ''
        return True

    except:
        log_tool.error("预期不为空，实际结果为空")
        raise



import logging
from logging.handlers import TimedRotatingFileHandler
from tools import os_tool
"""
封装log方法
"""
logger = logging.getLogger(__name__)
logger.setLevel(level=logging.INFO)
root_path = os_tool.get_root_path()+'logs/'
os_tool.mkdir(root_path)

handler = TimedRotatingFileHandler(root_path + 'info.log',when = 'd',interval = 1,backupCount=30,encoding='utf-8')
handler.setLevel(logging.INFO)
formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
handler.setFormatter(formatter)
logger.addHandler(handler)


handler2 = TimedRotatingFileHandler(root_path + 'error.log',when = 'd',interval = 1,backupCount=30,encoding='utf-8')
handler2.setLevel(logging.ERROR)
formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
handler2.setFormatter(formatter)
logger.addHandler(handler2)

handler3 = logging.StreamHandler()
handler3.setLevel(logging.DEBUG)
formatter = logging.Formatter()
handler3.setFormatter(formatter)
logger.addHandler(handler3)


def info(msg):
    logger.info(msg)


def debug(msg):
    logger.debug(msg)


def warning(msg):
    logger.warning(msg)


def error(msg):
    logger.error(msg)


def critical(msg):
    logger.critical(msg)




# -*- coding:utf-8 -*-
# Author : 小吴老师
# Data ：2019/7/11 18:31
import os
import shutil
import stat


def get_root_path():
    root_path = os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)).replace('\\', '/')
    print(root_path)
    print(root_path.find('venv'))
    if root_path.find('venv') > 0:
        root_path=root_path[:root_path.find('venv')-1]
    return root_path+'/'

def deldir(dir):
    if os.path.exists(dir):
        for file in os.listdir(dir):
            file = os.path.join(dir, file)
            if os.path.isdir(file):
                print("remove dir", file)
                os.chmod(file, stat.S_IWRITE|stat.S_IWOTH)
                deldir(file)
            elif os.path.isfile(file) :
                print("remove file", file)
                os.chmod(file, stat.S_IWRITE|stat.S_IWOTH)
                os.remove(file)
        shutil.rmtree(dir,True)

def mkdir(path):
    is_exists = os.path.exists(path)
    if not is_exists:
        os.makedirs(path)

def remove(path):
    is_exists = os.path.exists(path)
    if is_exists:
        os.remove(path)

def exists(file_or_path):
    is_exists = os.path.exists(file_or_path)
    return is_exists
#
# def copy_dir(source_path,target_path):
#     if not os.path.exists(target_path):
#         os.makedirs(target_path)
#
#     if os.path.exists(source_path):
#         # root 所指的是当前正在遍历的这个文件夹的本身的地址
#         # dirs 是一个 list，内容是该文件夹中所有的目录的名字(不包括子目录)
#         # files 同样是 list, 内容是该文件夹中所有的文件(不包括子目录)
#         for root, dirs, files in os.walk(source_path):
#             for file in files:
#                 src_file = os.path.join(root, file)
#                 shutil.copy(src_file, target_path)
#                 print(src_file)
#
#     print('copy files finished!')

def move(src_dir,target_dir):
    if not os.path.exists(target_dir):
        shutil.move(src_dir,target_dir)

def copy_dir(src_dir,target_dir):
    if not os.path.exists(target_dir):
        shutil.copytree(src_dir,target_dir)

def copy_file(src_file,target_dir):
    shutil.copy(src_file,target_dir)


# -*- coding:utf-8 -*-
# Author : 小吴老师
# Data ：2019/7/10 6:26

import configparser
import os


class ConfigTool:

    def __init__(self):
        root_path = os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)).replace('\\','/')
        file_path = '/config/config.ini'
        file_name = root_path + file_path
        print(file_name)
        self.config = configparser.ConfigParser()
        print(file_name)
        self.config.read(file_name)

    def get_conf(self,section,option):
        return self.config.get(section,option)


    def get_api_url(self,section):
        protocal = self.get_conf(section, 'protocal')
        host = self.get_conf(section, 'host')
        port = self.get_conf(section, 'port')

        url = protocal + '://' + host + ':' + port
        return url

    def get_db_dict(self,section):
        db_dict = dict()
        db_dict['host'] = self.get_conf(section, 'host')
        db_dict['port'] = int(self.get_conf(section, 'port'))
        db_dict['db'] = self.get_conf(section, 'db')
        db_dict['user'] = self.get_conf(section, 'user')
        db_dict['passwd'] = self.get_conf(section, 'passwd')
        db_dict['charset'] = self.get_conf(section, 'charset')
        print(type(db_dict))
        print(db_dict)
        return  db_dict



# -*- coding:utf-8 -*-
# Author : 小吴老师
# Data ：2019/7/10 6:26

import pymysql

def connect(**db):
    conn = pymysql.connect(**db)
    return conn


def query_one(sql,db):
    print(type(db))
    conn = connect(**db)
    cursor = conn.cursor(pymysql.cursors.DictCursor)

    try:
        # 执行sql语句
        cursor.execute(sql)
        row = cursor.fetchone()
        return row
    except Exception as  e:
        # 如果执行sql语句出现问题，则执行回滚操作
        print(e)
    finally:
        # 不论try中的代码是否抛出异常，这里都会执行
        # 关闭游标和数据库连接
        cursor.close()
        conn.close()



# -*- coding:utf-8 -*-
# Author : 小吴老师
# Data ：2019/7/31 18:56

import zipfile
import os


# zipfile解压
def unzip_file(zipfilename, unziptodir):
    if not os.path.exists(unziptodir): os.mkdir(unziptodir)
    zfobj = zipfile.ZipFile(zipfilename)
    for name in zfobj.namelist():
        name = name.replace('\\', '/')
        if name.endswith('/'):
            os.mkdir(os.path.join(unziptodir, name))
        else:
            ext_filename = os.path.join(unziptodir, name)
            ext_dir = os.path.dirname(ext_filename)
            if not os.path.exists(ext_dir): os.mkdir(ext_dir)
            outfile = open(ext_filename, 'wb')
            outfile.write(zfobj.read(name))
            outfile.close()


if __name__ == '__main__':
    unzip_file('C:/softwareData/PycharmProjects/test-ui-1/chrom_driver/chromedriver_win32.zip',
               'C:/softwareData/PycharmProjects/test-ui-1/chrom_driver')



import xlrd
import xlwt
from tools import os_tool

def write_excel(file_name,data_title,data_list,encoding='utf-8'):
    # 创建workbook和sheet对象 注意Workbook的开头W要大写
    workbook = xlwt.Workbook(encoding=encoding)
    # 添加一个名为sheet1的表
    sheet1 = workbook.add_sheet('sheet1', cell_overwrite_ok=True)

    # 向表头写入数据
    for i in range(len(data_title)):
        sheet1.write(0, i, data_title[i])

    # 向sheet写入数据
    for i in range(len(data_list)):
        for j in range(4):
            sheet1.write(i + 1, j, data_list[i][j])

    # 保存数据到‘Workbook2.xls’文件中
    workbook.save(file_name)
    print('创建execel完成！')

def _get_excel_dict(file):
    data = []
    wb = xlrd.open_workbook(filename=file)  # 打开文件
    # print(wb.sheet_names())  # 获取所有表格名字

    sheet1 = wb.sheet_by_index(0)  # 通过索引获取表格
    # print(sheet1)
    # print(sheet1.name, sheet1.nrows, sheet1.ncols)

    for i in range(1, sheet1.nrows):
        # l.append(sheet1.row_values(i))
        d = {}
        for j in range(sheet1.ncols):
            d[sheet1.row_values(0)[j]] = sheet1.row_values(i)[j]
        data.append(d)
    # print(l)
    return data


def _get_excel_list(file):
    data = []  # 声明变量
    wb = xlrd.open_workbook(filename=file)  # 打开文件
    sheet1 = wb.sheet_by_index(0)  # 通过索引获取表格sheet
    for i in range(1, sheet1.nrows):  # 循环行
        data.append(sheet1.row_values(i))  # 获取每行内容 并 添加进l
    return data

def _get_excel_ids(excel_list):
    ids_list = []
    for i in range(len(excel_list)):
        # 删除excel_list中每个小list的最后一个元素,并赋值给ids_pop
        ids_pop = excel_list[i].pop(0)
        # 将ids_pop添加到 ids_list 里面
        ids_list.append(ids_pop)
    return ids_list

def get_test_case(file):
    root_path = os_tool.get_root_path()
    data = {}
    case_list=_get_excel_list(root_path+file)
    case_ids=_get_excel_ids(case_list)
    data[0]=case_ids
    data[1]=case_list
    return data

if __name__ == '__main__':
    data = get_test_case("C:/softwareData/PycharmProjects/s00-wuling/documents/user/注册接口sign_up.xlsx")
    print(data[0])
    print(data[1])



# -*- coding:utf-8 -*-
# Author : 小吴老师
# Data ：2019/7/9 21:34

import random
import string
from datetime import time

import pinyin


# 1. 定义“获取性别”函数，函数名：get_sex()
# 2. 随机0和1,0代表男，1代表女
# 3. 打印日志
#       性别：0-男
#       性别：1-女
# 4. 返回性别（数字）
def random_sex():
    sex = random.randint(0,1)
    if sex == 0:
        print('性别：0-男')
    else:
        print('性别：1-女')
    return sex

# 1. 定义函数，函数名：get_name()
# 2. 需要支持指定性别，参数名sex
# 3. 提供3个字符串：百家姓、适合男性的字、适合女性的字
# 4. 姓名由3个字组成：姓+名1+名2
#       姓：从百家姓字符串随机1个
#       名1：若为男生，从boys中选1个字
#           若为女生，从girls里选1个字
#       名2：先随机0或1,0不需要第3个字，1需要第3个字
#           若需要第3个字，男生从boys中选1个，女生从girls中选1个
# 5. 返回名字（第1个字+第2个字+第3个字）
def random_name(sex=-1):
    if sex == -1:
        sex = random.randint(0,1)

    first_name = "赵钱孙李周吴郑王冯陈褚卫蒋沈韩杨朱秦尤许何吕施张孔曹严华" \
                 "金魏陶姜戚谢邹喻柏水窦章云苏潘葛奚范彭郎鲁韦昌马苗凤花方俞" \
                 "任袁柳酆鲍史唐费廉岑薛雷贺倪汤滕殷罗毕郝邬安常乐于时傅皮卞齐" \
                 "康伍余元卜顾孟平黄和穆萧尹姚邵湛汪祁毛禹狄米贝明臧计伏成戴谈" \
                 "宋茅庞熊纪舒屈项祝董梁杜阮蓝闵席季麻强贾路娄危江童颜郭梅盛林" \
                 "刁钟徐邱骆高夏蔡田樊胡凌霍虞万支柯咎管卢莫经房裘缪干解应宗宣丁" \
                 "贲邓郁单杭洪包诸左石崔吉钮龚程嵇邢滑裴陆荣翁荀羊於惠甄魏加封芮" \
                 "羿储靳汲邴糜松井段富巫乌焦巴弓牧隗山谷车侯宓蓬全郗班仰秋仲伊宫宁" \
                 "仇栾暴甘钭厉戎祖武符刘姜詹束龙叶幸司韶郜黎蓟薄印宿白怀蒲台从鄂索" \
                 "咸籍赖卓蔺屠蒙池乔阴郁胥能苍双闻莘党翟谭贡劳逄姬申扶堵冉宰郦雍" \
                 "却璩桑桂濮牛寿通边扈燕冀郏浦尚农温别庄晏柴瞿阎充慕连茹习宦艾鱼" \
                 "容向古易慎戈廖庚终暨居衡步都耿满弘匡国文寇广禄阙东殴殳沃利蔚" \
                 "越夔隆师巩厍聂晁勾敖融冷訾辛阚那简饶空曾毋沙乜养鞠须丰巢关蒯相" \
                 "查后江红游竺权逯盖益桓公万俟司马上官欧阳夏侯诸葛闻人东方赫连皇" \
                 "甫尉迟公羊澹台公冶宗政濮阳淳于仲孙太叔申屠公孙乐正轩辕令狐钟离" \
                 "闾丘长孙慕容鲜于宇文司徒司空亓官司寇仉督子车颛孙端木巫马公西漆" \
                 "雕乐正壤驷公良拓拔夹谷宰父谷粱晋楚阎法汝鄢涂钦段干百里东郭南门" \
                 "呼延归海羊舌微生岳帅缑亢况后有琴梁丘左丘东门西门商牟佘佴伯赏南" \
                 "宫墨哈谯笪年爱阳佟第五言福百家姓续"
    girl = "秀娟英华慧巧美娜静淑惠珠翠雅芝玉萍红娥玲芬芳燕彩春菊兰凤洁梅琳素云莲" \
           "真环雪荣爱妹霞香月莺媛艳瑞凡佳嘉琼勤珍贞莉桂娣叶璧璐娅琦晶妍茜秋珊莎" \
           "锦黛青倩婷姣婉娴瑾颖露瑶怡婵雁蓓纨仪荷丹蓉眉君琴蕊薇菁梦岚苑婕馨瑗琰" \
           "韵融园艺咏卿聪澜纯毓悦昭冰爽琬茗羽希宁欣飘育滢馥筠柔竹霭凝晓欢霄枫芸" \
           "菲寒伊亚宜可姬舒影荔枝思丽";
    boy = "伟刚勇毅俊峰强军平保东文辉力明永健世广志义兴良海山仁波宁贵福生龙元全国" \
          "胜学祥才发武新利清飞彬富顺信子杰涛昌成康星光天达安岩中茂进林有坚和彪博" \
          "诚先敬震振壮会思群豪心邦承乐绍功松善厚庆磊民友裕河哲江超浩亮政谦亨奇固" \
          "之轮翰朗伯宏言若鸣朋斌梁栋维启克伦翔旭鹏泽晨辰士以建家致树炎德行时泰盛" \
          "雄琛钧冠策腾楠榕风航弘";

    first = random.choice(first_name)
    names = boy if sex == 0 else girl
    second = random.choice(names)
    has_third = random.randint(0,1)
    third = random.choice(names) if has_third == 1 else ''
    full_name = first+second+third
    print('姓名：'+full_name)
    return full_name

# 1. 定义函数，函数名：get_pwd()
# 2. 密码长度8位，由大写字母、小写字母和数字组成
# 3. 至少包含1个大写字母、1个小写字母，1个数字
# 4. 其余5个字母随便取
# 5. 返回密码
def random_pwd():
    src = string.ascii_letters+string.digits
    pwd_list = random.sample(src,5)
    pwd_list.extend(random.sample(string.digits,1))
    pwd_list.extend(random.sample(string.ascii_uppercase,1))
    pwd_list.extend(random.sample(string.ascii_lowercase,1))
    random.shuffle(pwd_list)
    pwd = ''.join(pwd_list)
    print('密码：'+pwd)
    return pwd


'''
# 1. 定义函数，函数名：get_tell()
# 2. 前三位为号段，如186/135，从有效号段列表取
# 3. 至少包含1个大写字母、1个小写字母，1个数字
# 4. 其余5个字母随便取
# 5. 返回密码
'''
def random_tell():
    tel_first = ['139', '138', '137', '136', '135', '134',
                 '159', '158', '157', '150', '151', '152', '147',
                 '188', '187','182', '183', '184', '178', '130', '131',
                 '132', '156', '155', '186', '185', '145', '176',
                 '133', '153', '189', '180', '181', '177', '173']
    first = random.choice(tel_first)
    second = str(random.randint(0, 9999) + 10000)[1:]
    third = str(random.randint(0, 9999) + 10000)[1:]

    tell_num = first + second + third
    print('电话:'+tell_num)
    return tell_num


'''
# 1. 定义函数，函数名：get_addr()
# 2. 地址组成：省份+地区+路名+门牌号+房间号（楼层+号数）
#              eg：地址：上海市金山区河南广场33号1202室
# 3. 门牌号取值范围：11-150号
# 4. 房间号：
#       楼层高度范围：1-20层，不需前补0
#       房间号范围：1-20室，两位前补0（比如3，则改成03）
#       示例：12层第3个房间，房间号：1203室
# 5. 返回地址
'''
def random_addr():
    province ='上海市'
    districts = ['黄浦区','徐汇区','长宁区','静安区','普陀区','虹口区',
                 '闸北区','杨浦区','闵行区','宝山区','青浦区','松江区','嘉定区','奉贤区','金山区','浦东新区']
    road_list = '重庆大厦','黑龙江路','十梅庵街','遵义路','湘潭街',\
                '瑞金广场','仙山街','仙山东路','仙山西大厦','白沙河路',\
                '赵红广场','机场路','民航街','长城南路','流亭立交桥',\
                '虹桥广场','长城大厦','礼阳路','风岗街','中川路','白塔广场',\
                '兴阳路','文阳街','绣城路','河城大厦','锦城广场','崇阳街',\
                '华城路','康城街','正阳路','和阳广场','中城路','江城大厦',\
                '顺城路','安城街','山城广场','春城街','国城路','泰城街',\
                '德阳路','明阳大厦','春阳路','艳阳街','秋阳路','硕阳街',\
                '青威高速','瑞阳街','丰海路','双元大厦','惜福镇街道',\
                '夏庄街道','古庙工业园','中山街','太平路','广西街',\
                '潍县广场','博山大厦','湖南路','济宁街','芝罘路',\
                '易州广场','荷泽四路','荷泽二街','荷泽一路','荷泽三大厦',\
                '观海二广场','广西支街','观海一路','济宁支街','莒县路',\
                '平度广场','明水路','蒙阴大厦','青岛路','湖北街',\
                '江宁广场','郯城街','天津路','保定街','安徽路',\
                '河北大厦','黄岛路','北京街','莘县路','济南街',\
                '宁阳广场','日照街','德县路','新泰大厦','荷泽路',\
                '山西广场','沂水路','肥城街','兰山路','四方街','平原广场',\
                '泗水大厦','浙江路','曲阜街','寿康路','河南广场','泰安路',\
                '大沽街','红山峡支路','西陵峡一大厦','台西纬一广场',\
                '台西纬四街','台西纬二路','西陵峡二街','西陵峡三路',\
                '台西纬三广场','台西纬五路','明月峡大厦','青铜峡路',\
                '台西二街','观音峡广场','瞿塘峡街','团岛二路','团岛一街',\
                '台西三路','台西一大厦','郓城南路','团岛三街','刘家峡路',\
                '西藏二街','西藏一广场','台西四街','三门峡路','城武支大厦',\
                '红山峡路','郓城北广场','龙羊峡路','西陵峡街','台西五路',\
                '团岛四街','石村广场','巫峡大厦','四川路','寿张街',\
                '嘉祥路','南村广场','范县路','西康街','云南路','巨野大厦',\
                '西江广场','鱼台街','单县路','定陶街','滕县路','钜野广场',\
                '观城路','汶上大厦','朝城路','滋阳街','邹县广场','濮县街',\
                '磁山路','汶水街','西藏路','城武大厦','团岛路','南阳街',\
                '广州路','东平街','枣庄广场','贵州街','费县路','南海大厦',\
                '登州路','文登广场','信号山支路','延安一街','信号山路',\
                '兴安支街','福山支广场','红岛支大厦','莱芜二路','吴县一街',\
                '金口三路','金口一广场','伏龙山路','鱼山支街','观象二路',\
                '吴县二大厦','莱芜一广场','金口二街','海阳路','龙口街',\
                '恒山路','鱼山广场','掖县路','福山大厦','红岛路','常州街',\
                '大学广场','龙华街','齐河路','莱阳街','黄县路','张店大厦',\
                '祚山路','苏州街','华山路','伏龙街','江苏广场','龙江街',\
                '王村路','琴屿大厦','齐东路','京山广场','龙山路','牟平街',\
                '延安三路','延吉街','南京广场','东海东大厦','银川西路',\
                '海口街','山东路','绍兴广场','芝泉路','东海中街','宁夏路',\
                '香港西大厦','隆德广场','扬州街','郧阳路','太平角一街',\
                '宁国二支路','太平角二广场','天台东一路','太平角三大厦',\
                '漳州路一路','漳州街二街','宁国一支广场','太平角六街',\
                '太平角四路','天台东二街','太平角五路','宁国三大厦',\
                '澳门三路','江西支街','澳门二路','宁国四街','大尧一广场',\
                '咸阳支街','洪泽湖路','吴兴二大厦','澄海三路','天台一广场',\
                '新湛二路','三明北街','新湛支路','湛山五街','泰州三广场',\
                '湛山四大厦','闽江三路','澳门四街','南海支路','吴兴三广场',\
                '三明南路','湛山二街','二轻新村镇','江南大厦','吴兴一广场',\
                '珠海二街','嘉峪关路','高邮湖街','湛山三路','澳门六广场',\
                '泰州二路','东海一大厦','天台二路','微山湖街','洞庭湖广场',\
                '珠海支街','福州南路','澄海二街','泰州四路','香港中大厦',\
                '澳门五路','新湛三街','澳门一路','正阳关街','宁武关广场',\
                '闽江四街','新湛一路','宁国一大厦','王家麦岛','澳门七广场',\
                '泰州一路','泰州六街','大尧二路','青大一街','闽江二广场',\
                '闽江一大厦','屏东支路','湛山一街','东海西路',\
                '徐家麦岛函谷关广场','大尧三路','晓望支街','秀湛二路',\
                '逍遥三大厦','澳门九广场','泰州五街','澄海一路','澳门八街',\
                '福州北路','珠海一广场','宁国二路','临淮关大厦','燕儿岛路',\
                '紫荆关街','武胜关广场','逍遥一街','秀湛四路','居庸关街',\
                '山海关路','鄱阳湖大厦','新湛路','漳州街','仙游路','花莲街'
    district = random.choice(districts)
    road = random.choice(road_list)
    no = str(random.randint(11,150))+'号'
    room = str(random.randint(1,20))+str(random.randint(100,120))[1:]+'室'
    addr = province+district+road+no+room
    print('地址：'+addr)
    return addr

'''
# 1. 定义函数，函数名：get_email()
# 2. 邮箱组成：
#       首字符：只能是字母（大写或小写）
#       其余字符：大写字母、小写字母、数字、下划线
#       邮箱后缀：主流邮箱服务商，如@126.com、@gmail.com、@qq.com等
# 3. 邮箱名长度：6-18位
# 4. 返回邮箱
'''
def random_email():
    email_suffix = ['@gmail.com','@yahoo.com','@msn.com','@hotmail.com',
                    '@aol.com','@ask.com','@live.com','@qq.com',
                    '@0355.net','@163.com','@163.net','@263.net',
                    '@3721.net','@yeah.net','@googlemail.com','@126.com',
                    '@sina.com','@sohu.com','@yahoo.com.cn']
    first = random.choice(string.ascii_letters)
    num = string.ascii_letters+string.digits+"_"
    length = random.randint(5,17)
    second = ''.join(map(str,random.sample(num,length)))
    third = random.choice(email_suffix)
    email = first+second+third
    print('邮箱：'+email)
    return email

def random_name_pinyin(name=''):
    if name == '':
        name = random_name()
    if len(name) == 2:
        name_pinyin = pinyin.get(name, format='strip')
    else:
        name_pinyin = pinyin.get(name[0],format='strip')+pinyin.get_initial(name[1:],delimiter="")
    print('姓名（拼音）：'+name_pinyin)
    return name_pinyin

def random_number(min=0,max=1,step=1):
    num = random.randrange(min,max,step)
    print('随机数：'+str(num))
    return num

# 随机字母
def random_str_abc(num):
    str =''
    for i in range(num):
        str=str+random.choice(string.ascii_letters)
    return str


# 中文
def random_chinese():
    val = random.randint(0x4e00, 0x9fbf)
    return chr(val)

# 常用汉字
def random_gbk_chines():
    head = random.randint(0xb0, 0xf7)
    body = random.randint(0xa1, 0xf9)
    val = f'{head:x}{body:x}'
    str = bytes.fromhex(val).decode('gb2312')
    return str




# -*- coding:utf-8 -*-
# Author : 小吴老师
# Data ：2019/7/15 10:46
# !/usr/bin/python

from distutils.core import setup

setup(
    name="guoya-tools",  # 这里是pip项目发布的名称
    version="1.1.6",  # 版本号，数值大的会优先被pip
    keywords=["init", "auto-test"],
    description="to simplify auto test",
    long_description="A init package,to simplify develope auto test",
    license="MIT Licence",

    url="https://github.com/LudvikWoo/guoya-tools",  # 项目相关文件地址，一般是github
    author="wuling",
    author_email="wuling@guoyasoft.com",
    data_files =['init_tool.py'],
    packages=['tools'],
    platforms="python",
    install_requires=[
        'pinyin==0.4.0',
        'PyMySQL==0.9.3',
        'requests==2.22.0',
        'xlrd==1.2.0',
        'xlwt==1.3.0',
        'selenium==3.141.0',
        'pyyaml==5.1.1',
        'allure-pytest==2.7.0',
        'pytest==5.0.1'
    ]
)


# -*- coding:utf-8 -*-
# Author : 小吴老师
# Data ：2019/7/18 20:27
import os
import shutil
import stat
import subprocess
import yaml
import time
import requests

def get_yaml(yaml_path):
    with open(yaml_path,'r',encoding='utf-8') as f:
        content =yaml.load(f.read(),Loader=yaml.FullLoader)
    return content

def invoke(cmd):
    try:
        output, errors = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
        o = output.decode("utf-8")
        print(o)
        return o
    except Exception as e:
        print('执行命令失败，请检查环境配置')
        print(e)
        raise

def copy_file(src_file,target_dir):
    shutil.copy(src_file,target_dir)

def copy_dir(src_dir,target_dir):
    if not os.path.exists(target_dir):
        shutil.copytree(src_dir,target_dir)

def get_root_path():
    root_path = os.path.abspath(os.path.dirname(__file__)).replace('\\', '/')
    print(root_path)
    if root_path.find('venv') > 0:
        root_path=root_path[:root_path.find('venv')-1]
    return root_path+'/'

def mkdir(path):
    is_exists = os.path.exists(path)
    if not is_exists:
        os.makedirs(path)
def deldir(dir):
    if os.path.exists(dir):
        for file in os.listdir(dir):
            file = os.path.join(dir, file)
            if os.path.isdir(file):
                print("remove dir", file)
                os.chmod(file, stat.S_IWRITE|stat.S_IWOTH)
                deldir(file)
            elif os.path.isfile(file) :
                print("remove file", file)
                os.chmod(file, stat.S_IWRITE|stat.S_IWOTH)
                os.remove(file)
        shutil.rmtree(dir,True)

def copy_file(src_file,target_dir):
    shutil.copy(src_file,target_dir)


def down_big_file(srcUrl, localFile):
    print('%s\n --->>>\n  %s' % (srcUrl, localFile))
    startTime = time.time()
    with requests.get(srcUrl, stream=True) as r:
        contentLength = int(r.headers['content-length'])
        line = 'content-length: %dB/ %.2fKB/ %.2fMB'
        line = line % (contentLength, contentLength / 1024, contentLength / 1024 / 1024)
        print(line)
        print('正在下载中..............')
        downSize = 0
        with open(localFile, 'wb') as f:
            for chunk in r.iter_content(8192):
                if chunk:
                    f.write(chunk)
                downSize += len(chunk)
                line = '%d KB/s - %.2f MB， 共 %.2f MB'
                line = line % (
                downSize / 1024 / (time.time() - startTime), downSize / 1024 / 1024, contentLength / 1024 / 1024)
                print(line, end='\r')
                if downSize >= contentLength:
                    break
        timeCost = time.time() - startTime
        line = '共耗时: %.2f s, 平均速度: %.2f KB/s'
        line = line % (timeCost, downSize / 1024 / timeCost)
        print(line)

def init_ui_project():
    root_path = get_root_path()
    url = 'http://chromedriver.storage.googleapis.com/75.0.3770.90/chromedriver_win32.zip'
    os.makedirs(root_path + 'chrome_driver')
    down_big_file(url,root_path+'chrome_driver/chromedriver.exe')
    ## 先删除，再下载tools和ui工程
    tools_prj = 'c:/guoya/auto_test_init/guoya-tools'
    ui_prj = 'c:/guoya/auto_test_init/guoya-ui-test'
    deldir(tools_prj)
    deldir(ui_prj)
    mkdir(tools_prj)
    mkdir(ui_prj)
    cmd = 'git clone https://github.com/LudvikWoo/guoya-tools.git ' + tools_prj
    invoke(cmd)
    cmd = 'git clone https://github.com/LudvikWoo/guoya-ui-test.git ' + ui_prj
    invoke(cmd)

    ## 读取ui初始化配置文件
    y = get_yaml(ui_prj + '/init_ui_project.yaml')
    ## 复制文件夹
    dirs = y['dirs']
    for dir in dirs:
        copy_dir(ui_prj + '/' + dir, root_path + dir)
    ## 复制文件
    files = y['files']
    for file in files:
        copy_file(ui_prj + '/' + file, root_path)

if __name__ == '__main__':
    init_ui_project()